
Changelog
=========

0.6.0 (2014-02-04)
------------------

- Stop multiple prints for multiple keys
  [djowett]

0.5.0 (2011-08-30)
------------------

- Fix entry point, now targetting ``transmogrify``
  [aclark]

0.4.0 (2011-07-31)
------------------

- Note the existence of ``collective.transmogrifier.sections.logger`` which does
  something similar.
  [aclark]

0.3.0 (2011-07-31)
------------------

- Fix blueprint name, should be something unique like ``transmogrify.print``
  (instead of ``print``).
  [aclark]

- Show ``keys`` being used in README
  [aclark]

0.2.0 (2011-07-31)
------------------

- Fix package data, setup.py missing ``include_package_data``.
  [aclark]

0.1.0 (2011-07-31)
------------------

- Initial release
  [aclark]
